]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
sr: Fix/document probe names.
[libsigrok.git] / sigrok.h
index e12c5bc5acc6b4479f88cdb07e42f26c17b05b63..10a483f377fb6ee47d3b245856c831f725f515c3 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -66,12 +66,12 @@ extern "C" {
 #define SR_HZ_TO_NS(n) (1000000000 / (n))
 
 /* libsigrok loglevels. */
-#define SR_LOG_NONE               0 /**< Output no messages at all. */
+#define SR_LOG_NONE           0 /**< Output no messages at all. */
 #define SR_LOG_ERR            1 /**< Output error messages. */
-#define SR_LOG_WARN               2 /**< Output warnings. */
-#define SR_LOG_INFO               3 /**< Output informational messages. */
+#define SR_LOG_WARN           2 /**< Output warnings. */
+#define SR_LOG_INFO           3 /**< Output informational messages. */
 #define SR_LOG_DBG            4 /**< Output debug messages. */
-#define SR_LOG_SPEW               5 /**< Output very noisy debug messages. */
+#define SR_LOG_SPEW           5 /**< Output very noisy debug messages. */
 
 /*
  * Use SR_API to mark public API symbols, and SR_PRIV for private symbols.
@@ -94,7 +94,7 @@ extern "C" {
 
 typedef int (*sr_receive_data_callback) (int fd, int revents, void *user_data);
 
/* Data types used by hardware plugins for set_configuration() */
 enum {
        SR_T_UINT64,
        SR_T_CHAR,
@@ -131,7 +131,7 @@ struct sr_datafeed_logic {
 struct sr_input {
        struct sr_input_format *format;
        char *param;
-       struct sr_device *vdevice;
+       struct sr_dev *vdev;
 };
 
 struct sr_input_format {
@@ -144,7 +144,7 @@ struct sr_input_format {
 
 struct sr_output {
        struct sr_output_format *format;
-       struct sr_device *device;
+       struct sr_dev *dev;
        char *param;
        void *internal;
 };
@@ -171,11 +171,11 @@ struct sr_datastore {
  * This represents a generic device connected to the system.
  * For device-specific information, ask the plugin. The plugin_index refers
  * to the device index within that plugin; it may be handling more than one
* device. All relevant plugin calls take a device_index parameter for this.
  */
-struct sr_device {
+struct sr_dev {
        /* Which plugin handles this device */
-       struct sr_device_plugin *plugin;
+       struct sr_dev_plugin *plugin;
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
        /* List of struct sr_probe* */
@@ -210,7 +210,7 @@ enum {
        /*--- Device types --------------------------------------------------*/
 
        /** The device is demo device. */
-       SR_HWCAP_DEMO_DEVICE,
+       SR_HWCAP_DEMO_DEV,
 
        /*--- Device options ------------------------------------------------*/
 
@@ -270,26 +270,26 @@ enum {
 };
 
 struct sr_hwcap_option {
-       int capability;
+       int hwcap;
        int type;
        char *description;
        char *shortname;
 };
 
-struct sr_device_instance {
+struct sr_dev_inst {
        int index;
        int status;
-       int instance_type;
+       int inst_type;
        char *vendor;
        char *model;
        char *version;
        void *priv;
 };
 
-/* sr_device_instance types */
+/* sr_dev_inst types */
 enum {
-       SR_USB_INSTANCE,
-       SR_SERIAL_INSTANCE,
+       SR_USB_INST,
+       SR_SERIAL_INST,
 };
 
 /* Device instance status */
@@ -310,8 +310,8 @@ enum {
 
 /* Device info IDs */
 enum {
-       /* struct sr_device_instance for this specific device */
-       SR_DI_INSTANCE,
+       /* struct sr_dev_inst for this specific device */
+       SR_DI_INST,
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
        /* The probe names on this device */
@@ -338,28 +338,28 @@ struct sr_samplerates {
        uint64_t *list;
 };
 
-struct sr_device_plugin {
+struct sr_dev_plugin {
        /* Plugin-specific */
        char *name;
        char *longname;
        int api_version;
-       int (*init) (const char *deviceinfo);
-       void (*cleanup) (void);
+       int (*init) (const char *devinfo);
+       int (*cleanup) (void);
 
        /* Device-specific */
-       int (*opendev) (int device_index);
-       int (*closedev) (int device_index);
-       void *(*get_device_info) (int device_index, int device_info_id);
-       int (*get_status) (int device_index);
-       int *(*get_capabilities) (void);
-       int (*set_configuration) (int device_index, int capability, void *value);
-       int (*start_acquisition) (int device_index, gpointer session_device_id);
-       void (*stop_acquisition) (int device_index, gpointer session_device_id);
+       int (*dev_open) (int dev_index);
+       int (*dev_close) (int dev_index);
+       void *(*dev_info_get) (int dev_index, int dev_info_id);
+       int (*dev_status_get) (int dev_index);
+       int *(*hwcap_get_all) (void);
+       int (*dev_config_set) (int dev_index, int hwcap, void *value);
+       int (*dev_acquisition_start) (int dev_index, gpointer session_dev_id);
+       int (*dev_acquisition_stop) (int dev_index, gpointer session_dev_id);
 };
 
 struct sr_session {
-       /* List of struct sr_device* */
-       GSList *devices;
+       /* List of struct sr_dev* */
+       GSList *devs;
        /* list of sr_receive_data_callback */
        GSList *datafeed_callbacks;
        GTimeVal starttime;
@@ -94,7 +94,7 @@ extern "C" {
 typedef int (*sr_receive_data_callback) (int fd, int revents, void *user_data);
 
-/* Data types used by hardware plugins for set_configuration() */
+/* Data types used by hardware plugins for dev_config_set() */
 enum {
        SR_T_UINT64,
@@ -171,11 +171,11 @@ struct sr_datastore {
  * For device-specific information, ask the plugin. The plugin_index refers
  * to the device index within that plugin; it may be handling more than one
- * device. All relevant plugin calls take a device_index parameter for this.
+ * device. All relevant plugin calls take a dev_index parameter for this.
  */